@@ -1,15 +1,15 @@
 from .authorize import setAccount,setPassword
-from .file import ls,mkdir,rm,cp,mv,rename,download,downloadFolder,upload
+from .file import ls,mkdir,rm,cp,mv,rename,download,downloadFolder,upload,ls_l,getFileProperty
 from .exceptions import InputError
 
 __all__=[
     'setAccount','setPassword',
-    'ls','mkdir','rm','cp','mv','rename','download','downloadFolder','upload',
+    'ls','mkdir','rm','cp','mv','rename','download','downloadFolder','upload','ls_l','getFileProperty',
     'InputError'
 ]
 
 
-__version__='0.9.2'
+__version__='0.9.3'
 __license__='GPL-2.0 License'
 __author__='Tiancheng Jiao'
 __url__='https://github.com/jtc1246/autoDropbox'
